Index: uspace/lib/gui/terminal.c
===================================================================
--- uspace/lib/gui/terminal.c	(revision 06808543ddcf3db81aa4fd6bcb19218aa143260a)
+++ uspace/lib/gui/terminal.c	(revision 4d8002de0e91d359818180c5e990eb5bf5e63aff)
@@ -42,4 +42,5 @@
 #include <io/concaps.h>
 #include <io/console.h>
+#include <loc.h>
 #include <task.h>
 #include <adt/list.h>
Index: uspace/lib/gui/terminal.h
===================================================================
--- uspace/lib/gui/terminal.h	(revision 06808543ddcf3db81aa4fd6bcb19218aa143260a)
+++ uspace/lib/gui/terminal.h	(revision 4d8002de0e91d359818180c5e990eb5bf5e63aff)
@@ -42,4 +42,5 @@
 #include <io/chargrid.h>
 #include <io/con_srv.h>
+#include <loc.h>
 #include <adt/list.h>
 #include <adt/prodcons.h>
Index: uspace/lib/gui/window.c
===================================================================
--- uspace/lib/gui/window.c	(revision 06808543ddcf3db81aa4fd6bcb19218aa143260a)
+++ uspace/lib/gui/window.c	(revision 4d8002de0e91d359818180c5e990eb5bf5e63aff)
@@ -519,7 +519,4 @@
 
 	if (width > 0 && height > 0) {
-		/* Notify compositor. */
-		//win_damage(win->osess, x, y, width, height);
-
 		rect.p0.x = x;
 		rect.p0.y = y;
Index: uspace/lib/gui/window.h
===================================================================
--- uspace/lib/gui/window.h	(revision 06808543ddcf3db81aa4fd6bcb19218aa143260a)
+++ uspace/lib/gui/window.h	(revision 4d8002de0e91d359818180c5e990eb5bf5e63aff)
@@ -61,10 +61,10 @@
 	widget_t *focus; /**< Widget owning the keyboard or NULL. */
 	fibril_mutex_t guard; /**< Mutex guarding window surface. */
-	surface_t *surface; /**< Window surface shared with compositor. */
+	surface_t *surface; /**< Window surface shared with display server. */
 	gfx_bitmap_t *bitmap; /**< Window bitmap */
 };
 
 /**
  * Allocate all resources for new window and register it in the compositor.
  * If the window is declared as main, its closure causes termination of the
  * whole application. Note that opened window does not have any surface yet.
@@ -75,7 +75,7 @@
 /**
  * Post resize event into event loop. Window negotiates new surface with
  * compositor and asks all widgets in the tree to calculate their new properties
  * and to paint themselves on the new surface (top-bottom order). Should be
  * called also after opening new window to obtain surface.
  */
 extern void window_resize(window_t *, sysarg_t, sysarg_t, sysarg_t, sysarg_t,
@@ -94,6 +94,6 @@
 
 /**
  * Post damage event into event loop. Handler informs compositor to update the
  * window surface on the screen. Should be called by widget after painting
  * itself or copying its buffer onto window surface.
  */
@@ -124,5 +124,5 @@
 
 /**
  * Initiate the closing cascade for the window. First, compositor deallocates
  * output resources, prepares special closing input event for the window and
  * deallocates input resources after the event is dispatched. When window
@@ -61,10 +61,10 @@
 
 /**
- * Allocate all resources for new window and register it in the compositor.
+ * Allocate all resources for new window and register it in the display server.
  * If the window is declared as main, its closure causes termination of the
  * whole application. Note that opened window does not have any surface yet.
@@ -75,7 +75,7 @@
 /**
  * Post resize event into event loop. Window negotiates new surface with
- * compositor and asks all widgets in the tree to calculate their new properties
- * and to paint themselves on the new surface (top-bottom order). Should be
- * called also after opening new window to obtain surface.
+ * display server and asks all widgets in the tree to calculate their new
+ * properties and to paint themselves on the new surface (top-bottom order).
+ * Should be called also after opening new window to obtain surface.
  */
 extern void window_resize(window_t *, sysarg_t, sysarg_t, sysarg_t, sysarg_t,
@@ -94,6 +94,6 @@
 
 /**
- * Post damage event into event loop. Handler informs compositor to update the
- * window surface on the screen. Should be called by widget after painting
+ * Post damage event into event loop. Handler informs display server to update
+ * the window surface on the screen. Should be called by widget after painting
  * itself or copying its buffer onto window surface.
  */
@@ -124,5 +124,5 @@
 
 /**
- * Initiate the closing cascade for the window. First, compositor deallocates
+ * Initiate the closing cascade for the window. First, display sever deallocates
  * output resources, prepares special closing input event for the window and
  * deallocates input resources after the event is dispatched. When window
